@@ -60,6 +60,12 @@ class AnalysisForm(forms.Form):
     SEM_PRED_STYLE = (('A','Average'),
                         ('S','Sum'),
                         ('W','Weighted'))
+    LEX_SCALE_CHOICES = (('C','CELEX'),
+                            ('W','Whole corpus'),
+                            ('S','Speaker'),
+                            ('G','Same gender'),
+                            ('A','Same age'),
+                            ('D','Dialog'),)
     #FETCH_CHOICES = (('PrevSemPred','PrevSemPred'),
     #                'FollSemPred','FollSemPred')
     measure = forms.CharField(label='Measure')
@@ -74,12 +80,12 @@ class AnalysisForm(forms.Form):
     segmentalDurations = forms.BooleanField(initial=True,required=False,label='Segmental duration')
     category = forms.CharField(label='Category source')
     category.widget = forms.CheckboxSelectMultiple(choices=CAT_CHOICES)
-    frequency = forms.CharField(label='Frequency source')
-    frequency.widget = forms.CheckboxSelectMultiple(choices=FREQ_CHOICES)
-    nd = forms.CharField(label='Neighbourhood density source')
-    nd.widget = forms.CheckboxSelectMultiple(choices=NEIGH_DEN_CHOICES)
-    phonotactic = forms.CharField(label='Phonotactic probability source')
-    phonotactic.widget = forms.CheckboxSelectMultiple(choices=PHONO_PROB_CHOICES)
+    frequency = forms.BooleanField(initial=True,required=False,label='Frequency')
+    nd = forms.BooleanField(initial=True,required=False,label='Neighbourhood density')
+    phonotactic = forms.BooleanField(initial=True,required=False,label='Phonotactic probability')
+    lexical_scale = forms.CharField(label = 'Corpora to use for lexical statistics')
+    lexical_scale.widget = forms.CheckboxSelectMultiple(choices=LEX_SCALE_CHOICES)
+    additional_phono_stats = forms.BooleanField(initial=True,required=False,label='Additional phonological statistics')
     gender = forms.BooleanField(initial=True,required=False,label='Gender')
     age = forms.BooleanField(initial=True,required=False,label='Age')
     globalSpeakingRate = forms.BooleanField(initial=True,required=False,label='Global speaking rate')
@@ -118,10 +124,19 @@ class AnalysisForm(forms.Form):
         if form['wordDuration']:
             wanted_fields.extend(['WordDuration','BaselineDur'])
 
-        if 'B' in form['frequency']:
-            wanted_fields.extend(['BuckeyeFrequency'])
-        if 'C' in form['frequency']:
-            wanted_fields.extend(['CelexFrequency'])
+        if form['frequency']:
+            if 'C' in form['lexical_scale']:
+                wanted_fields.extend(['CelexFrequency'])
+            if 'W' in form['lexical_scale']:
+                wanted_fields.extend(['BuckeyeFrequency'])
+            if 'S' in form['lexical_scale']:
+                wanted_fields.extend(['SpeakerFrequency'])
+            if 'A' in form['lexical_scale']:
+                wanted_fields.extend(['AgeFrequency'])
+            if 'G' in form['lexical_scale']:
+                wanted_fields.extend(['GenderFrequency'])
+            if 'D' in form['lexical_scale']:
+                wanted_fields.extend(['DialogFrequency'])
 
         if form['gender']:
             wanted_fields.extend(['SpeakerGender'])
@@ -132,17 +147,39 @@ class AnalysisForm(forms.Form):
             wanted_fields.extend(['OrthoLength'])
         if form['phonoLength']:
             wanted_fields.extend(['PhonoLength'])
-        if 'B' in form['nd']:
-            wanted_fields.extend(['BuckeyeNeighDen','BuckeyeFWND'])
-        if 'PS' in form['nd']:
+        if form['nd']:
+            if 'C' in form['lexical_scale']:
+                wanted_fields.extend(['CelexNeighDen','CelexFWND'])
+            if 'W' in form['lexical_scale']:
+                wanted_fields.extend(['BuckeyeNeighDen','BuckeyeFWND'])
+            if 'S' in form['lexical_scale']:
+                wanted_fields.extend(['SpeakerNeighDen','SpeakerFWND'])
+            if 'A' in form['lexical_scale']:
+                wanted_fields.extend(['AgeNeighDen','AgeFWND'])
+            if 'G' in form['lexical_scale']:
+                wanted_fields.extend(['GenderNeighDen','GenderFWND'])
+            if 'D' in form['lexical_scale']:
+                wanted_fields.extend(['DialogNeighDen','DialogFWND'])
+
+        if form['additional_phono_stats']:
             wanted_fields.extend(['PhonoStatsNeighDen'])
+            wanted_fields.extend(['PhonoStatsBlickPhono'])
+            wanted_fields.extend(['PhonoStatsSPhoneProb','PhonoStatsBiPhoneProb'])
 
         if 'VB' in form['phonotactic']:
-            wanted_fields.extend(['BuckeyeSPhoneProb','BuckeyeBiPhoneProb'])
-        if 'B' in form['phonotactic']:
-            wanted_fields.extend(['PhonoStatsBlickPhono'])
-        if 'VP' in form['phonotactic']:
-            wanted_fields.extend(['PhonoStatsSPhoneProb','PhonoStatsBiPhoneProb'])
+            if 'C' in form['lexical_scale']:
+                wanted_fields.extend(['CelexSPhoneProb','CelexBiPhoneProb'])
+            if 'W' in form['lexical_scale']:
+                wanted_fields.extend(['BuckeyeSPhoneProb','BuckeyeBiPhoneProb'])
+            if 'S' in form['lexical_scale']:
+                wanted_fields.extend(['SpeakerSPhoneProb','SpeakerBiPhoneProb'])
+            if 'A' in form['lexical_scale']:
+                wanted_fields.extend(['AgeSPhoneProb','AgeBiPhoneProb'])
+            if 'G' in form['lexical_scale']:
+                wanted_fields.extend(['GenderSPhoneProb','GenderBiPhoneProb'])
+            if 'D' in form['lexical_scale']:
+                wanted_fields.extend(['DialogSPhoneProb','DialogBiPhoneProb'])
+
         for w in eval(form['sem_pred_window']):
             for s in eval(form['sem_pred_style']):
                 if form['prev_sem_pred']:
@@ -165,13 +202,15 @@ class AnalysisForm(forms.Form):
         fieldsets = ((None,
                       {'fields':('measure')}),
                      ('Lexical type factors',
-                      {'fields':('frequency',
+                      {'fields':('lexical_scale',
+                                'frequency',
                                  'category',
                                  'nd',
                                  'phonotactic',
                                  'orthoLength',
                                  'phonoLength',
-                                 'numSylls')}),
+                                 'numSylls',
+                                 'additional_phono_stats')}),
                      ('Lexical token factors',
                       {'fields':('wordDuration',
                                  'segmentalDurations')}),
